@@ -114,6 +114,9 @@ static unsigned long long last_block(struct thread_data *td, struct fio_file *f,
 	if (max_size > f->real_file_size)
 		max_size = f->real_file_size;
 
+	if (td->o.zone_range)
+		max_size = td->o.zone_range;
+
 	max_blocks = max_size / (unsigned long long) td->o.ba[ddir];
 	if (!max_blocks)
 		return 0;
@@ -493,12 +496,17 @@ static enum fio_ddir rate_ddir(struct thread_data *td, enum fio_ddir ddir)
 
 	/*
 	 * We are going to sleep, ensure that we flush anything pending as
-	 * not to skew our latency numbers
+	 * not to skew our latency numbers.
+	 *
+	 * Changed to only monitor 'in flight' requests here instead of the
+	 * td->cur_depth, b/c td->cur_depth does not accurately represent
+	 * io's that have been actually submitted to an async engine,
+	 * and cur_depth is meaningless for sync engines.
 	 */
-	if (td->cur_depth) {
+	if (td->io_u_in_flight) {
 		int fio_unused ret;
 
-		ret = io_u_queued_complete(td, td->cur_depth, NULL);
+		ret = io_u_queued_complete(td, td->io_u_in_flight, NULL);
 	}
 
 	fio_gettime(&t, NULL);
@@ -656,7 +664,8 @@ static int fill_io_u(struct thread_data *td, struct io_u *io_u)
 	 */
 	if (td->zone_bytes >= td->o.zone_size) {
 		td->zone_bytes = 0;
-		io_u->file->last_pos += td->o.zone_skip;
+		io_u->file->file_offset += td->o.zone_range + td->o.zone_skip;
+		io_u->file->last_pos = io_u->file->file_offset;
 		td->io_skip_bytes += td->o.zone_skip;
 	}
 
@@ -1138,6 +1147,7 @@ static void small_content_scramble(struct io_u *io_u)
 
 	p = io_u->xfer_buf;
 	boffset = io_u->offset;
+	io_u->buf_filled_len = 0;
 
 	for (i = 0; i < nr_blocks; i++) {
 		/*
